Trait Tuple

pub trait Tuple: Tuple { }
Available on crate feature nightly only.
A tuple.

Do not rely on the exact definition of this trait, as it may change depending on the enabled features.

Implementors

Source

impl<T: Tuple> Tuple for T